class InvalidHostURL (Exception, ) : pass


class AuthenticationError (Exception, ) : pass


class UncheckedRequest (Exception, ) : pass


class InvalidRequest (Exception, ) : pass


class InvalidResponse (Exception, ) : pass


class Disconnected (Exception, ) : pass


class ConnectionLost (Exception, ) : pass


class ConnectionError (Exception, ) : pass


class RpcError (Exception, ) : pass


class ThisIsNotHeader (Exception, ) : pass


class ThisIsNotValidHeader (Exception, ) : pass


class StopReceiveData (Exception, ) : pass


